# Table of Contents

- [aws-applications-modeling-best-practices](<./aws-applications-modeling-best-practices.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [AWS Applications Modeling Best Practices](<./AWS-Applications-Modeling-Best-Practices.md>)
  - [Amazon Web Services (IaaS)](<./AWS-Applications-Modeling-Best-Practices/Amazon-Web-Services-IaaS.md>)
